@@ -46,11 +46,19 @@ print_dentry(addr, sw, subdir, parent)
 	memread(addr, sizeof(de), &de, "dentry");
 
 	if (subdir) {
+#if SUBLEVEL>=16
+		for (next = (addr_t)de.d_subdirs.next; next != (addr_t)&((struct dentry *)addr)->d_subdirs; next = (addr_t)de.d_u.d_child.next) {
+			child = next - OFFSET(struct dentry, d_u.d_child);
+			memread(child, sizeof(de), &de, "dentry");
+			(void)print_dentry(child, 0, 0, 0);
+		}
+#else
 		for (next = (addr_t)de.d_subdirs.next; next != (addr_t)&((struct dentry *)addr)->d_subdirs; next = (addr_t)de.d_child.next) {
 			child = next - OFFSET(struct dentry, d_child);
 			memread(child, sizeof(de), &de, "dentry");
 			(void)print_dentry(child, 0, 0, 0);
 		}
+#endif
 		return 0;
 	}
 
@@ -59,7 +67,11 @@ print_dentry(addr, sw, subdir, parent)
 	mprintf(" %c%c%c%c%c ",
 		(de.d_hash.next   !=&((struct dentry *)addr)->d_hash   )? 'H': '-',
 		(de.d_lru.next    !=&((struct dentry *)addr)->d_lru    )? 'L': '-',
+#if SUBLEVEL>=16
+		(de.d_u.d_child.next  !=&((struct dentry *)addr)->d_u.d_child  )? 'C': '-',
+#else
 		(de.d_child.next  !=&((struct dentry *)addr)->d_child  )? 'C': '-',
+#endif
 		(de.d_subdirs.next!=&((struct dentry *)addr)->d_subdirs)? 'S': '-',
 		(de.d_alias.next  !=&((struct dentry *)addr)->d_alias  )? 'A': '-');
 	mprintf(FPTR " " FPTR " %2x ", de.d_op, de.d_sb, de.d_flags);
@@ -218,9 +230,16 @@ print_inode(addr, full)
 			inode.i_ctime.tv_sec);
 		mprintf("\tblocks:    %ld  (* blksize %ld)\n", inode.i_blocks, inode.i_blksize);
 		mprintf("\tversion:   %ld\n", inode.i_version);
+#ifdef _inode_has_i_mutex
+		mprintf("\tmutex:       ");
+		mprint_mutex(&inode.i_mutex);
+		mprintf("\n");
+#endif
+#ifdef _inode_has_i_sem
 		mprintf("\tsem:       ");
 		mprint_semaphore(&inode.i_sem);
 		mprintf("\n");
+#endif
 		mprintf("\top:        " FPTR "  ", inode.i_op);
 		p = getsymstr((addr_t)inode.i_op);
 		if (p)
@@ -301,7 +320,11 @@ print_superblock(addr, full)
 		mprintf("\tdquot_operations: " FPTR "\n", sb.dq_op);
 		mprintf("\tmagic:            %lx\n", sb.s_magic);
 		mprintf("\tlock:             ");
+#if SUBLEVEL>=16
+		mprint_mutex(&sb.s_lock);
+#else
 		mprint_semaphore(&sb.s_lock);
+#endif
 		mprintf("\n");
 		mprintf("\tid:               ");
 		mprintstr(sb.s_id, sizeof(sb.s_id));
