@@ -49,17 +49,21 @@ print_page(addr, lru)
 
 #ifdef _page_has__mapcount
 	n = ATOMIC_READ(pg._mapcount);
-	mprintf((n == -1)? "%4d ": "%4x", n);
+	mprintf((n == -1)? "%4d": "%4x", n);
 #else
 #ifdef _page_has_mapcount
 	n = pg.mapcount;
-	mprintf((n == -1)? "%4d ": "%4x", n);
+	mprintf((n == -1)? "%4d": "%4x", n);
 #else
 	mprintf(FPTR, pg.pte.direct);
 #endif
 #endif
 
+#ifdef _page_has_u
+	mprintf(" %8lx", pg.u.private);
+#else
 	mprintf(" %8lx", pg.private);
+#endif
 #if defined(WANT_PAGE_VIRTUAL)
 	mprintf(" " FPTR, pg.virtual);
 #endif
