@@ -49,8 +49,13 @@ print_zone(addr, full)
 	mprintf("free_pages         %lx\n", zone.free_pages);
 	mprintf("pages_min/low/high %lx/%lx/%lx\n",
 		zone.pages_min, zone.pages_low, zone.pages_high);
+#ifdef _zone_has_nr_scan_active
+	mprintf("nr_active (scan)   %lx  (%lx)\n", zone.nr_active, zone.nr_scan_active);
+	mprintf("nr_inactive (scan) %lx  (%lx)\n", zone.nr_inactive, zone.nr_scan_inactive);
+#else
 	mprintf("nr_active          %lx\n", zone.nr_active);
 	mprintf("nr_inactive        %lx\n", zone.nr_inactive);
+#endif
 	mprintf("all_unreclaimable  %x\n", zone.all_unreclaimable);
 	mprintf("pages_scanned      %lx\n", zone.pages_scanned);
 	mprintf("FREE " SPTR " " SPTR "  " SPTR "\n", "NEXT", "PREV", "MAP");
