@@ -10,17 +10,26 @@
 #include <net/ip_fib.h>
 
 /* begin linux/net/ipv4/route.c */
+#if SUBLEVEL>=13
+struct rt_hash_bucket {
+	struct rtable	*chain;
+};
+#else
 struct rt_hash_bucket {
 	struct rtable	*chain;
 	spinlock_t	lock;
 } __attribute__((__aligned__(8)));
+#endif
 /* end linux/net/ipv4/route.c */
 
 /* begin linux/net/ipv4/fib_hash.c */
-struct fn_zone
-{
+struct fn_zone {
 	struct fn_zone  *fz_next;	/* Next not empty zone  */
+#if SUBLEVEL>=9
+	struct hlist_head *fz_hash;	/* Hash table pointer   */
+#else
 	struct fib_node **fz_hash;	/* Hash table pointer   */
+#endif
 	int		fz_nent;	/* Number of entries    */
 
 	int		fz_divisor;	/* Hash divisor         */
@@ -30,8 +39,7 @@ struct fn_zone
 	u32		fz_mask;
 };
 
-struct fn_hash
-{
+struct fn_hash {
 	struct fn_zone	*fn_zones[33];
 	struct fn_zone	*fn_zone_list;
 };
