@@ -38,16 +38,21 @@ print_files_struct(addr)
 	memread(addr, sizeof(files), &files, "files_struct");
 	mprintf("%3x ", ATOMIC_READ(files.count));
 #ifdef _files_struct_has_fdtab
-	mprintf("%5d %5d %5d", files.fdtab.max_fds, files.fdtab.max_fdset, files.fdtab.next_fd);
-	mprintf(" " FPTR " " FPTR " " FPTR "\n", files.fdtab.fd, files.fdtab.close_on_exec, files.fdtab.open_fds);
-	if ((addr_t)files.fdtab.fd == addr + OFFSET(struct files_struct, fd_array))
+	struct fdtable fdtab;
+	if ((addr_t)files.fdt == addr + OFFSET(struct files_struct, fdtab))
+		m_memcpy(&fdtab, &files.fdtab, sizeof(fdtab));
+	else
+		memread((addr_t)files.fdt, sizeof(fdtab), &fdtab, "fdtable");
+	mprintf("%5d %5d %5d", fdtab.max_fds, fdtab.max_fdset, fdtab.next_fd);
+	mprintf(" " FPTR " " FPTR " " FPTR "\n", fdtab.fd, fdtab.close_on_exec, fdtab.open_fds);
+	if ((addr_t)fdtab.fd == addr + OFFSET(struct files_struct, fd_array))
 		m_memcpy(fds, files.fd_array, sizeof(files.fd_array));
 	else
-		memread((addr_t)files.fdtab.fd, sizeof(fds), &fds, "file");
-	if ((addr_t)files.fdtab.close_on_exec == addr + OFFSET(struct files_struct, close_on_exec_init))
+		memread((addr_t)fdtab.fd, sizeof(fds), fds, "file");
+	if ((addr_t)fdtab.close_on_exec == addr + OFFSET(struct files_struct, close_on_exec_init))
 		cfd = files.close_on_exec_init;
 	else
-		memread((addr_t)files.fdtab.close_on_exec, sizeof(fd_set), &cfd, "close_on_exec");
+		memread((addr_t)fdtab.close_on_exec, sizeof(fd_set), &cfd, "close_on_exec");
 #else /*_files_struct_has_fdtab*/
 	mprintf("%5d %5d %5d", files.max_fds, files.max_fdset, files.next_fd);
 	mprintf(" " FPTR " " FPTR " " FPTR "\n", files.fd, files.close_on_exec, files.open_fds);
@@ -63,7 +68,7 @@ print_files_struct(addr)
 
 	cnt = 0;
 #ifdef _files_struct_has_fdtab
-	for (i = 0; i < LENGTHOF(fds) && i < files.fdtab.max_fds; i++)
+	for (i = 0; i < LENGTHOF(fds) && i < fdtab.max_fds; i++)
 #else
 	for (i = 0; i < LENGTHOF(fds) && i < files.max_fds; i++)
 #endif /*_files_struct_has_fdtab*/
