@@ -106,7 +106,7 @@ void
 prhead_usb_driver()
 {
 	mprintf(SPTR" "SPTR" "SPTR" "SPTR" "SPTR" "SPTR" NAME\n",
-		"ADDR", "OWNER", "PROBE", "DISCON", "IOCTL", "ID_TABLE");
+		"ADDR", "PROBE", "DISCON", "IOCTL", "SUSPEND", "RESUME", "ID_TABLE");
 }
 
 PRIVATE const char *
@@ -142,14 +142,15 @@ print_usb_driver(addr, nflag)
 	mprintf(FPTR " ", addr);
 
 	if (nflag) {
-		mprintf(SPTR " ", S(getsymstr_func((addr_t)ud.owner)));
 		mprintf(SPTR " ", S(getsymstr_func((addr_t)ud.probe)));
 		mprintf(SPTR " ", S(getsymstr_func((addr_t)ud.disconnect)));
 		mprintf(SPTR " ", S(getsymstr_func((addr_t)ud.ioctl)));
+		mprintf(SPTR " ", S(getsymstr_func((addr_t)ud.suspend)));
+		mprintf(SPTR " ", S(getsymstr_func((addr_t)ud.resume)));
 		mprintf(SPTR " ", S(getsymstr_func((addr_t)ud.id_table)));
 	} else {
 		mprintf(FPTR " " FPTR " " FPTR " " FPTR " " FPTR " ",
-			ud.owner, ud.probe, ud.disconnect, ud.ioctl, ud.id_table);
+			ud.probe, ud.disconnect, ud.ioctl, ud.suspend, ud.resume, ud.id_table);
 	}
 	memread((addr_t)ud.name, sizeof(buf), buf, "name");
 	mprintstr(buf, sizeof(buf));
