@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2003 ASANO Masahiro
+ * Copyright (C) 2000-2006 ASANO Masahiro
  */
 
 #include <string.h>
@@ -211,7 +211,8 @@ trace()
 				retad = *(unsigned int *)&stack[esp - stacktop];
 				if (retad < kmem_low)
 					continue;
-				if ((sym = searchsym_byaddr(retad)) != NULL &&
+				sym = searchsym_byaddr(retad);
+				if (sym != NULL && sym->addr != retad &&
 				    (sym->type == 'T' || sym->type == 't' || sym->type == 0))
 					break;	/*found*/
 				sym = NULL;
