@@ -15,6 +15,7 @@ extern char *symname;
 extern char *physname;
 extern int quiet;
 extern int noprompt;
+extern int debug;
 extern FILE *fp;	/* output device */
 extern addr_t kmem_low, kmem_high;
 extern addr_t high_memory;
@@ -48,6 +49,7 @@ extern jmp_buf *except_jmpbuf;
 #define THROW(s)	(except_message = s, longjmp(*except_jmpbuf, 1))
 #define THROWF(f,s)	(sprintf(except_message_buf,f,s), except_message = except_message_buf, longjmp(*except_jmpbuf, 1))
 #define THROWF2(f,s,s2)	(sprintf(except_message_buf,f,s,s2), except_message = except_message_buf, longjmp(*except_jmpbuf, 1))
+#define THROWF3(f,s,s2,s3)	(sprintf(except_message_buf,f,s,s2,s3), except_message = except_message_buf, longjmp(*except_jmpbuf, 1))
 
 typedef struct commandtable {
 	char *name;			/* command name */
