@@ -88,6 +88,10 @@ extern int getmsyms_fromfile(const char *, addr_t, addr_t, addr_t);
 extern int getinfo_fromtask(addr_t addr, addr_t *ip, addr_t *sp, addr_t *stack);
 struct semaphore;
 extern void mprint_semaphore(struct semaphore *);
+#if PATCHLEVEL>=6 && SUBLEVEL>=16
+struct mutex;
+extern void mprint_mutex(struct mutex *);
+#endif
 extern void mprint_jif(unsigned long);
 
 extern addr_t init_task_addr;
