@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2003 ASANO Masahiro
+ * Copyright (C) 2000-2005 ASANO Masahiro
  */
 
 #include "def.h"
@@ -176,3 +176,25 @@ print_xfs_bmbt_rec(addr, size, needswap)
 	}
 	return 0;
 }
+
+void
+prhead_xfs_bmbt_irec()
+{
+	mprintf(SPTR "      STARTOFF    STARTBLOCK BLOCKCOUNT STATE\n", "ADDR");
+}
+
+addr_t
+print_xfs_bmbt_irec(addr)
+	addr_t addr;
+{
+	struct xfs_bmbt_irec irec;
+
+	mprintf(FPTR " ", addr);
+	memread(addr, sizeof(irec), &irec, "xfs_bmbt_irec");
+
+	mprintf("%13llx %13llx %10llx",
+		(__u64)irec.br_startoff, (__u64)irec.br_startblock,
+		(__u64)irec.br_blockcount);
+	mprintf(irec.br_state? " unwrittren\n": "\n");
+	return 0;
+}
