@@ -7,7 +7,16 @@
 #define __KERNEL__
 #include <xfs.h>
 #include <xfs_log.h>
+#include <xfs_inum.h>
 #include <xfs_trans.h>
+#include <xfs_dir.h>
+#include <xfs_dir2.h>
+#include <xfs_bmap_btree.h>
+#include <xfs_dir_sf.h>
+#include <xfs_dir2_sf.h>
+#include <xfs_attr_sf.h>
+#include <xfs_dinode.h>
+#include <xfs_inode.h>
 #include <xfs_buf_item.h>
 #include <xfs_inode_item.h>
 #include <xfs_extfree_item.h>
