@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2003 ASANO Masahiro
+ * Copyright (C) 2000-2005 ASANO Masahiro
  */
 
 #include <unistd.h>
@@ -15,6 +15,11 @@ const commandtable_t command_xfs_bmbt_rec =
 	{"xfs_bmbt_rec", xfs_bmbt_rec, "[-s] address", "[XFS] print xfs_bmbt_rec"};
 extern addr_t print_xfs_bmbt_rec();
 
+PRIVATE addr_t xfs_bmbt_irec();
+const commandtable_t command_xfs_bmbt_irec =
+	{"xfs_bmbt_irec", xfs_bmbt_irec, "address", "[XFS] print xfs_bmbt_irec"};
+extern addr_t print_xfs_bmbt_irec();
+
 PRIVATE addr_t
 xfs_inode()
 {
@@ -66,3 +71,28 @@ xfs_bmbt_rec()
 
 	return print_xfs_bmbt_rec(addr, size, swap);
 }
+
+PRIVATE addr_t
+xfs_bmbt_irec()
+{
+	int i, c;
+	addr_t addr = 0;
+
+	while ((c = getopt(argcnt, args, "")) != EOF) {
+		switch (c) {
+		default:
+			THROW(usage);
+		}
+	}
+
+	if (argcnt > optind) {
+		prhead_xfs_bmbt_irec();
+		for (i = optind; i < argcnt; i++) {
+			addr = getvalue(args[i]);
+			addr = print_xfs_bmbt_irec(addr);
+		}
+	} else {
+		THROW(usage);
+	}
+	return addr;
+}
