@@ -12,7 +12,7 @@ extern addr_t print_xfs_mount();
 
 PRIVATE addr_t xfs_perag();
 const commandtable_t command_xfs_perag =
-	{"xfs_perag", xfs_perag, "[-i] [-l] address", "[XFS] print xfs_perag_t table"};
+	{"xfs_perag", xfs_perag, "address", "[XFS] print xfs_perag_t table"};
 extern addr_t print_xfs_perag();
 
 PRIVATE addr_t
